@@ -1,30 +1,22 @@
-// Copyright 2013-2015, The Gtk-rs Project Developers.
-// See the COPYRIGHT file at the top-level directory of this distribution.
-// Licensed under the MIT license, see the LICENSE file or <http://opensource.org/licenses/MIT>
+// Take a look at the license at the top of the repository in the LICENSE file.
 
-use enums::{PathDataType, Status};
-use ffi;
-use ffi::cairo_path_t;
+use crate::enums::PathDataType;
+use crate::ffi::cairo_path_t;
 use std::fmt;
 use std::iter::Iterator;
+use std::ptr;
 
 #[derive(Debug)]
-pub struct Path(*mut cairo_path_t);
+pub struct Path(ptr::NonNull<cairo_path_t>);
 
 impl Path {
     pub fn as_ptr(&self) -> *mut cairo_path_t {
-        self.0
-    }
-
-    pub fn ensure_status(&self) {
-        unsafe {
-            let ptr: *mut cairo_path_t = self.as_ptr();
-            Status::from((*ptr).status).ensure_valid()
-        }
+        self.0.as_ptr()
     }
 
     pub unsafe fn from_raw_full(pointer: *mut cairo_path_t) -> Path {
-        Path(pointer)
+        assert!(!pointer.is_null());
+        Path(ptr::NonNull::new_unchecked(pointer))
     }
 
     pub fn iter(&self) -> PathSegments {
@@ -75,12 +67,12 @@ impl fmt::Display for PathSegment {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         write!(
             f,
-            "PathSegment::{}",
+            "Self::{}",
             match *self {
-                PathSegment::MoveTo(_) => "MoveTo",
-                PathSegment::LineTo(_) => "LineTo",
-                PathSegment::CurveTo(_, _, _) => "CurveTo",
-                PathSegment::ClosePath => "ClosePath",
+                Self::MoveTo(_) => "MoveTo",
+                Self::LineTo(_) => "LineTo",
+                Self::CurveTo(_, _, _) => "CurveTo",
+                Self::ClosePath => "ClosePath",
             }
         )
     }
@@ -133,17 +125,17 @@ fn to_tuple(pair: &[f64; 2]) -> (f64, f64) {
 #[cfg(test)]
 mod tests {
     use super::*;
-    use context::*;
-    use enums::Format;
-    use image_surface::*;
+    use crate::context::*;
+    use crate::enums::Format;
+    use crate::image_surface::*;
 
     fn make_cr() -> Context {
         let surface = ImageSurface::create(Format::Rgb24, 1, 1).unwrap();
 
-        Context::new(&surface)
+        Context::new(&surface).expect("Can't create a Cairo context")
     }
 
-    fn assert_path_equals_segments(expected: &Path, actual: &Vec<PathSegment>) {
+    fn assert_path_equals_segments(expected: &Path, actual: &[PathSegment]) {
         // First ensure the lengths are equal
 
         let expected_iter = expected.iter();
@@ -156,9 +148,8 @@ mod tests {
         let expected_iter = expected.iter();
         let actual_iter = actual.iter();
 
-        let mut iter = expected_iter.zip(actual_iter);
-
-        while let Some((e, a)) = iter.next() {
+        let iter = expected_iter.zip(actual_iter);
+        for (e, a) in iter {
             assert_eq!(e, *a);
         }
     }
@@ -167,7 +158,7 @@ mod tests {
     fn empty_path_doesnt_iter() {
         let cr = make_cr();
 
-        let path = cr.copy_path();
+        let path = cr.copy_path().expect("Invalid context");
 
         assert!(path.iter().next().is_none());
     }
@@ -178,9 +169,9 @@ mod tests {
 
         cr.move_to(1.0, 2.0);
 
-        let path = cr.copy_path();
+        let path = cr.copy_path().expect("Invalid path");
 
-        assert_path_equals_segments(&path, &vec![PathSegment::MoveTo((1.0, 2.0))]);
+        assert_path_equals_segments(&path, &[PathSegment::MoveTo((1.0, 2.0))]);
     }
 
     #[test]
@@ -191,11 +182,11 @@ mod tests {
         cr.line_to(3.0, 4.0);
         cr.move_to(5.0, 6.0);
 
-        let path = cr.copy_path();
+        let path = cr.copy_path().expect("Invalid path");
 
         assert_path_equals_segments(
             &path,
-            &vec![
+            &[
                 PathSegment::MoveTo((1.0, 2.0)),
                 PathSegment::LineTo((3.0, 4.0)),
                 PathSegment::MoveTo((5.0, 6.0)),
@@ -210,14 +201,14 @@ mod tests {
         cr.move_to(1.0, 2.0);
         cr.close_path();
 
-        let path = cr.copy_path();
+        let path = cr.copy_path().expect("Invalid path");
 
         // Note that Cairo represents a close_path as closepath+moveto,
         // so that the next subpath will have a starting point,
         // from the extra moveto.
         assert_path_equals_segments(
             &path,
-            &vec![
+            &[
                 PathSegment::MoveTo((1.0, 2.0)),
                 PathSegment::ClosePath,
                 PathSegment::MoveTo((1.0, 2.0)),
@@ -233,11 +224,11 @@ mod tests {
         cr.close_path();
         cr.line_to(9.0, 10.0);
 
-        let path = cr.copy_path();
+        let path = cr.copy_path().expect("Invalid path");
 
         assert_path_equals_segments(
             &path,
-            &vec![
+            &[
                 PathSegment::MoveTo((1.0, 2.0)),
                 PathSegment::CurveTo((3.0, 4.0), (5.0, 6.0), (7.0, 8.0)),
                 PathSegment::ClosePath,
@@ -246,5 +237,4 @@ mod tests {
             ],
         );
     }
-
 }
